@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.92'; # VERSION
+our $VERSION = '1.93'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -124,7 +124,9 @@ sub gather_file_dist_ini
     $content .= "\n";
     
     $content .= "[\@Author::Plicease]\n"
-             .  "release_tests = " . $self->include_tests ."\n"
+             .  (__PACKAGE__->VERSION ? ":version      = @{[ __PACKAGE__->VERSION ]}\n" : '')
+             .  "travis_status = 1\n"
+             .  "release_tests = @{[ $self->include_tests ]}\n"
              .  "installer     = Author::Plicease::MakeMaker\n"
              .  "\n";
     
@@ -316,7 +318,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.92
+version 1.93
 
 =head1 DESCRIPTION
 
