@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Special prereq handling
-our $VERSION = '1.92'; # VERSION
+our $VERSION = '1.93'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -36,6 +36,7 @@ sub register_prereqs
     Mojolicious                           4.31
     Role::Tiny                            1.003001
     Test::More                            0.94
+    Test::Exit                            0.11
   );
   
   foreach my $upgrade (@{ $self->upgrade })
@@ -154,7 +155,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 1.92
+version 1.93
 
 =head1 SYNOPSIS
 
@@ -228,6 +229,10 @@ Recommended if PerlX::Maybe is required.
 
 Recommended if Mojolicious or AnyEvent modules are required.
 
+=item Test::Exit
+
+Require 0.11 for dealing with C<exit> inside and C<eval>.
+
 =back
 
 =head1 SEE ALSO
